@@ -4,11 +4,11 @@ use warnings;
 
 package Dist::Zilla::Plugin::Regenerate::AfterReleasers;
 
-our $VERSION = '0.001001';
+our $VERSION = '0.001002';
 
 # ABSTRACT: Tickle plugins that do "AfterRelease" from regenerate
 
-our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+our $AUTHORITY = 'cpan:DBOOK'; # AUTHORITY
 
 use Moose qw( with has around );
 use Safe::Isa qw( $_does );
@@ -69,7 +69,7 @@ Dist::Zilla::Plugin::Regenerate::AfterReleasers - Tickle plugins that do "AfterR
 
 =head1 VERSION
 
-version 0.001001
+version 0.001002
 
 =head1 SYNOPSIS
 
@@ -110,7 +110,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2016-2017 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
